api.system.services.v1 package — Argus-Toolbelt 1.0 documentation

# api.system.services.v1 package

## Submodules

## api.system.services.v1.status module

Autogenerated API

`api.system.services.v1.status.` `get_service_status`(json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch system status for bound services (INTERNAL)

  Returns: | {“offset”: 375, “limit”: 571, “responseCode”: 200, “count”: 394, “data”: [{“state”: “STOPPED”, “packageVersion”: “Compare leader spend soon forward that teach.”, “serviceName”: “Ok away alone develop.”, “serviceID”: “Listen indeed tax TV that.”, “systemLoadAverage”: 94, “percentHeapUsed”: 41, “percentNonHeapUsed”: 404, “responseTimeInNanos”: 500}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Job president kind long attack source trial.”, “messageTemplate”: “White yeah task relationship least.”, “field”: “Season better building effort try participant.”, “parameter”: {}, “timestamp”: 353672652}], “currentPage”: 507, “size”: 743}

## Module contents